==> alliance-5.0-20020701.tar.gz: alliance-5.0/dreal/src/GMV_dialog.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   DREAL                           |
|                                                             |
| File    :                  Dialog.h                         |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                  28.03.95                         |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef DREAL_VIEW_DIALOG
# define DREAL_VIEW_DIALOG

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  extern DrealDialogItem DrealViewZoomSetDialog;
  extern DrealDialogItem DrealViewZoomGotoDialog;
  extern DrealDialogItem DrealViewMoveSetDialog;
  extern DrealDialogItem DrealViewGridXDialog;
  extern DrealDialogItem DrealViewGridYDialog;

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                       Callback View Dialog                  |
|                                                             |
\------------------------------------------------------------*/

  extern void CallbackViewZoomGotoOk();
  extern void CallbackViewZoomGotoCancel();
  extern void CallbackViewZoomSetOk();
  extern void CallbackViewZoomSetCancel();
  extern void CallbackViewMoveSetOk();
  extern void CallbackViewMoveSetCancel();
  extern void CallbackViewGridXOk();
  extern void CallbackViewGridXCancel();
  extern void CallbackViewGridYOk();
  extern void CallbackViewGridYCancel();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/dreal/src/GMV_dialog.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   DREAL                           |
|                                                             |
| File    :                  Dialog.h                         |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                  28.03.95                         |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef DREAL_VIEW_DIALOG
# define DREAL_VIEW_DIALOG

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  extern DrealDialogItem DrealViewZoomSetDialog;
  extern DrealDialogItem DrealViewZoomGotoDialog;
  extern DrealDialogItem DrealViewMoveSetDialog;
  extern DrealDialogItem DrealViewGridXDialog;
  extern DrealDialogItem DrealViewGridYDialog;

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                       Callback View Dialog                  |
|                                                             |
\------------------------------------------------------------*/

  extern void CallbackViewZoomGotoOk();
  extern void CallbackViewZoomGotoCancel();
  extern void CallbackViewZoomSetOk();
  extern void CallbackViewZoomSetCancel();
  extern void CallbackViewMoveSetOk();
  extern void CallbackViewMoveSetCancel();
  extern void CallbackViewGridXOk();
  extern void CallbackViewGridXCancel();
  extern void CallbackViewGridYOk();
  extern void CallbackViewGridYCancel();

# endif
